pub enum ExecuteMsg {
SetFee {
fee_type: Fees,
module_name: String,
fee_name: String,
data: Binary,
},
RemoveFee {
fee_type: Fees,
module_name: String,
fee_name: String,
},
Distribute {
fee_type: Fees,
module_name: String,
custom_payment_addresses: Option<Vec<CustomPaymentAddress>>,
},
LockExecute {},
Receive(Cw20ReceiveMsg),
}Variants
SetFee
Admin message.
Creates a new fee configuration. Fees are tied to a module with a fee name.
RemoveFee
Admin message.
Removes a fee configuration.
Distribute
Public message.
Distributes the sent funds according to the fee configuration. Custom payment addresses can be specified for overriding the default payment addresses.
LockExecute
Fields
Hub message.
Lock the execute entry point. Can only be called by the hub module.
Receive(Cw20ReceiveMsg)