pub struct FixedFeeResponse {
pub module_name: String,
pub fee_name: String,
pub address: Option<String>,
pub value: Uint128,
}Fields
module_name: Stringfee_name: Stringaddress: Option<String>value: Uint128Trait Implementations
Sourceimpl Clone for FixedFeeResponse
impl Clone for FixedFeeResponse
Sourcefn clone(&self) -> FixedFeeResponse
fn clone(&self) -> FixedFeeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FixedFeeResponse
impl Debug for FixedFeeResponse
Sourceimpl<'de> Deserialize<'de> for FixedFeeResponse
impl<'de> Deserialize<'de> for FixedFeeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FixedFeeResponse
impl JsonSchema for FixedFeeResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FixedFeeResponse
impl PartialEq for FixedFeeResponse
Sourceimpl Serialize for FixedFeeResponse
impl Serialize for FixedFeeResponse
impl StructuralPartialEq for FixedFeeResponse