Enum komple_framework_fee_module::msg::QueryMsg
source · pub enum QueryMsg {
Config {},
PercentageFee {
module_name: String,
fee_name: String,
},
FixedFee {
module_name: String,
fee_name: String,
},
PercentageFees {
module_name: String,
start_after: Option<String>,
limit: Option<u32>,
},
FixedFees {
module_name: String,
start_after: Option<String>,
limit: Option<u32>,
},
TotalPercentageFees {
module_name: String,
start_after: Option<String>,
limit: Option<u32>,
},
TotalFixedFees {
module_name: String,
start_after: Option<String>,
limit: Option<u32>,
},
Keys {
fee_type: Fees,
start_after: Option<String>,
limit: Option<u32>,
},
}Variants
Config
Fields
Gets the contract’s config.
PercentageFee
Gets the fee configuration for a module and fee name. Used for percentage fees.
FixedFee
Gets the fee configuration for a module and fee name. Used for fixed fees.
PercentageFees
Gets the fee configurations for a module with pagination. Used for percentage fees.
FixedFees
Gets the fee configurations for a module with pagination. Used for fixed fees.
TotalPercentageFees
Gets the sum of all the percentages for a given module.
TotalFixedFees
Gets the sum of all the fixed amounts for a given module.
Keys
Gets all the module names and fee names for a given fee type.